pub enum Fault {
Throw(Val),
Bug(String),
}Expand description
A type error is a throw the program may catch, not a second error system.
Bug is uncatchable and means an invariant of this file was violated.
Variants